- Added functions :func:`xoutil.objects.dict_merge`,
  :func:`xoutil.types.are_instances` and :func:`xoutil.types.no_instances`.

- Deprecated function :func:`xoutil.objects.smart_getattr`.  Use
  :func:`xoutil.objects.get_first_of` instead.
